@@ -38,7 +38,7 @@ void ExportAddressbookJobInterfaceTestImpl::exportResourceToArchive(const QStrin
     slotAddressbookJobTerminated();
 }
 
-QVector<Utils::AkonadiInstanceInfo> ExportAddressbookJobInterfaceTestImpl::listOfResource()
+QList<Utils::AkonadiInstanceInfo> ExportAddressbookJobInterfaceTestImpl::listOfResource()
 {
     return mListAkonadiInstanceInfo;
 }
@@ -96,3 +96,5 @@ void ExportAddressbookJobInterfaceTestImpl::backupAddressBookResourceFile(const
     connect(job, &TestBackupResourceFileJob::info, this, &ExportAddressbookJobInterfaceTestImpl::info);
     job->start();
 }
+
+#include "moc_exportaddressbookjobinterfacetestimpl.cpp"
