@@ -18,14 +18,11 @@ public:
 protected:
     void convertCollectionToRealPath(KConfigGroup &group, const QString &currentKey) override;
     void convertCollectionListToRealPath(KConfigGroup &group, const QString &currentKey) override;
-    Q_REQUIRED_RESULT Akonadi::Collection::Id convertFolderPathToCollectionId(const QString &path) override;
+    [[nodiscard]] Akonadi::Collection::Id convertFolderPathToCollectionId(const QString &path) override;
     void exportResourceToArchive(const QString &archivePath, const QString &url, const QString &identifier) override;
-    Q_REQUIRED_RESULT QVector<Utils::AkonadiInstanceInfo> listOfResource() override;
-    Q_REQUIRED_RESULT QString resourcePath(const QString &agentIdentifier, const QString &defaultPath = QString()) const override;
+    [[nodiscard]] QList<Utils::AkonadiInstanceInfo> listOfResource() override;
+    [[nodiscard]] QString resourcePath(const QString &agentIdentifier, const QString &defaultPath = QString()) const override;
     void backupAddressBookResourceFile(const QString &agentIdentifier, const QString &defaultPath) override;
-    Q_REQUIRED_RESULT QString adaptNewResourceUrl(bool overwriteResources, const KSharedConfig::Ptr &resourceConfig, const QString &storePath) override;
-    Q_REQUIRED_RESULT QString createResource(const QString &resources,
-                                             const QString &name,
-                                             const QMap<QString, QVariant> &settings,
-                                             bool synchronizeTree) override;
+    [[nodiscard]] QString adaptNewResourceUrl(bool overwriteResources, const KSharedConfig::Ptr &resourceConfig, const QString &storePath) override;
+    [[nodiscard]] QString createResource(const QString &resources, const QString &name, const QMap<QString, QVariant> &settings, bool synchronizeTree) override;
 };
