@@ -20,7 +20,7 @@ ExportAlarmJobInterfaceTestImpl::ExportAlarmJobInterfaceTestImpl(QObject *parent
 
 ExportAlarmJobInterfaceTestImpl::~ExportAlarmJobInterfaceTestImpl() = default;
 
-QVector<Utils::AkonadiInstanceInfo> ExportAlarmJobInterfaceTestImpl::listOfResource()
+QList<Utils::AkonadiInstanceInfo> ExportAlarmJobInterfaceTestImpl::listOfResource()
 {
     return mListAkonadiInstanceInfo;
 }
@@ -88,3 +88,5 @@ ExportAlarmJobInterfaceTestImpl::createResource(const QString &resources, const
     Q_UNREACHABLE();
     return {};
 }
+
+#include "moc_exportalarmjobinterfacetestimpl.cpp"
