@@ -35,7 +35,7 @@ void ExportNotesJobInterfaceTest::exportNote()
     QFETCH(Utils::StoredTypes, options);
     std::unique_ptr<TestExportFile> file{new TestExportFile(this)};
     file->setPathConfig(configpath);
-    QVector<Utils::AkonadiInstanceInfo> lstInfo;
+    QList<Utils::AkonadiInstanceInfo> lstInfo;
     Utils::AkonadiInstanceInfo info;
     info.identifier = QStringLiteral("akonadi_akonotes_resource_1");
     lstInfo << info;
@@ -52,3 +52,5 @@ void ExportNotesJobInterfaceTest::exportNote()
     file->start();
     delete exportNote;
 }
+
+#include "moc_exportnotesjobinterfacetest.cpp"
