@@ -26,7 +26,7 @@ void ExportNotesJobInterfaceTestImpl::convertCollectionIdsToRealPath(KConfigGrou
     resourceConverterTest.convertCollectionIdsToRealPath(selectFolderNoteGroup, selectFolderNoteGroupStr);
 }
 
-QVector<Utils::AkonadiInstanceInfo> ExportNotesJobInterfaceTestImpl::listOfResource()
+QList<Utils::AkonadiInstanceInfo> ExportNotesJobInterfaceTestImpl::listOfResource()
 {
     return mListAkonadiInstanceInfo;
 }
@@ -71,3 +71,5 @@ ExportNotesJobInterfaceTestImpl::createResource(const QString &resources, const
     Q_UNREACHABLE();
     return {};
 }
+
+#include "moc_exportnotesjobinterfacetestimpl.cpp"
