@@ -15,7 +15,7 @@ public:
     explicit TestBackupResourceFileJob(QObject *parent = nullptr);
     ~TestBackupResourceFileJob() override;
 
-    Q_REQUIRED_RESULT QString resourcePath(const QString &identifier) const override;
+    [[nodiscard]] QString resourcePath(const QString &identifier) const override;
     void setTestPath(const QString &str);
 
 private:
