@@ -1052,8 +1052,8 @@ void ImportMailJobInterface::copyMailArchiveConfig(const KSharedConfig::Ptr &arc
 
 void ImportMailJobInterface::copyUnifiedMailBoxConfig(const KSharedConfig::Ptr &archiveConfigOrigin, const KSharedConfig::Ptr &archiveConfigDestination)
 {
-    auto group = archiveConfigOrigin->group("UnifiedMailboxes");
-    auto groupCopy = archiveConfigDestination->group("UnifiedMailboxes");
+    auto group = archiveConfigOrigin->group(QStringLiteral("UnifiedMailboxes"));
+    auto groupCopy = archiveConfigDestination->group(QStringLiteral("UnifiedMailboxes"));
     const auto boxGroups = group.groupList();
     for (const auto &str : boxGroups) {
         KConfigGroup oldGroup = group.group(str);
@@ -1109,11 +1109,7 @@ void ImportMailJobInterface::importTemplatesConfig(const KArchiveFile *templates
         // Identity
         if (str.startsWith(templateGroupIdentityPattern)) {
             bool found = false;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            const int identity = str.rightRef(str.length() - templateGroupIdentityPattern.length()).toInt(&found);
-#else
             const int identity = QStringView(str).right(str.length() - templateGroupIdentityPattern.length()).toInt(&found);
-#endif
             if (found) {
                 KConfigGroup oldGroup = templateConfig->group(str);
                 if (mHashIdentity.contains(identity)) {
@@ -1451,3 +1447,5 @@ void ImportMailJobInterface::convertCollectionStrToAkonadiId(const KSharedConfig
         (void)convertRealPathToCollection(eventGroup, key, false);
     }
 }
+
+#include "moc_importmailjobinterface.cpp"
