@@ -20,15 +20,15 @@ public:
     void start() override;
 
 protected:
-    Q_REQUIRED_RESULT virtual QString configLocation() const;
+    [[nodiscard]] virtual QString configLocation() const;
     virtual void synchronizeResource(const QStringList &lst) = 0;
-    Q_REQUIRED_RESULT virtual QString adaptResourcePath(const KSharedConfigPtr &resourceConfig, const QString &storedData) = 0;
+    [[nodiscard]] virtual QString adaptResourcePath(const KSharedConfigPtr &resourceConfig, const QString &storedData) = 0;
     void slotNextStep() override;
-    Q_REQUIRED_RESULT QString installConfigLocation() const;
-    Q_REQUIRED_RESULT QString applicationName() const override;
+    [[nodiscard]] QString installConfigLocation() const;
+    [[nodiscard]] QString applicationName() const override;
 
 private:
-    Q_REQUIRED_RESULT bool isAConfigFile(const QString &name) const override;
+    [[nodiscard]] bool isAConfigFile(const QString &name) const override;
     void importKNoteGlobalSettings(const KArchiveFile *kmailsnippet, const QString &configrc, const QString &filename, const QString &prefix);
     void restoreConfig();
     void restoreData();
