@@ -15,13 +15,8 @@
 
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
-#ifdef USE_KUSERFEEDBACK_QT6
 #include <KUserFeedbackQt6/FeedbackConfigWidget>
 #include <KUserFeedbackQt6/Provider>
-#else
-#include <KUserFeedback/FeedbackConfigWidget>
-#include <KUserFeedback/Provider>
-#endif
 #endif
 
 #include <KWindowConfig>
@@ -92,14 +87,16 @@ void PimDataExporterConfigureDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(600, 400));
-    KConfigGroup group(KSharedConfig::openStateConfig(), myPimDataExporterConfigureDialogGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myPimDataExporterConfigureDialogGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void PimDataExporterConfigureDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), myPimDataExporterConfigureDialogGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myPimDataExporterConfigureDialogGroupName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
+
+#include "moc_pimdataexporterconfiguredialog.cpp"
