@@ -82,7 +82,7 @@ void SelectionTypeDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(600, 400));
-    KConfigGroup group(KSharedConfig::openStateConfig(), myConfigSelectionTypeDialogDialog);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myConfigSelectionTypeDialogDialog));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
     loadDefaultTemplate();
@@ -90,7 +90,7 @@ void SelectionTypeDialog::readConfig()
 
 void SelectionTypeDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), myConfigSelectionTypeDialogDialog);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myConfigSelectionTypeDialogDialog));
     KWindowConfig::saveWindowSize(windowHandle(), group);
 }
 
@@ -150,3 +150,5 @@ void SelectionTypeDialog::loadDefaultTemplate()
 {
     mSelectionTreeWidget->loadDefaultTemplate();
 }
+
+#include "moc_selectiontypedialog.cpp"
