@@ -44,13 +44,8 @@
 #include <dialog/pimdataexporterconfiguredialog.h>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
-#ifdef USE_KUSERFEEDBACK_QT6
 #include <KUserFeedbackQt6/NotificationPopup>
 #include <KUserFeedbackQt6/Provider>
-#else
-#include <KUserFeedback/NotificationPopup>
-#include <KUserFeedback/Provider>
-#endif
 #endif
 
 PimDataExporterWindow::PimDataExporterWindow(QWidget *parent)
@@ -429,3 +424,5 @@ void PimDataExporterWindow::slotShowCurrentArchiveInformations()
         dlg.exec();
     }
 }
+
+#include "moc_pimdataexporterwindow.cpp"
